/*
 * xrick/src/syssnd.c
 *
 * This source code file is part of the xrick distribution, and as such is
 * copyrighted. Please read the README file in the root directory of the
 * distribution for information about copyrights, trademarks, license,
 * disclaimers, etc.
 */

//#include <SDL.h>
#include <gpstdlib.h>
#include <gpmm.h>
#include "dat_snd.c"

#include "system.h"
#include "game.h"
#include "syssnd.h"
#include "debug.h"

#define SDL_MIX_MAXVOLUME 0xFF

#define ADJVOL(S) (((S)*sndVol)/SDL_MIX_MAXVOLUME)

static U8 isAudioActive = FALSE;
static channel_t channel[SYSSND_MIXCHANNELS];

static U8 sndVol = SDL_MIX_MAXVOLUME;  /* internal volume */
static U8 sndUVol = SYSSND_MAXVOL;  /* user-selected volume */
static U8 sndMute = FALSE;  /* mute flag */

//static SDL_mutex *sndlock;

/*
 * Callback -- this is also where all sound mixing is done
 *
 * Note: it may not be that much a good idea to do all the mixing here ; it
 * may be more efficient to mix samples every frame, or maybe everytime a
 * new sound is sent to be played. I don't know.
 */
void syssnd_callback(UNUSED(void *userdata), U8 *stream, int len)
{
}

void
syssnd_init(void)
{
  GpPcmInit(PCM_M11,PCM_8BIT);
  isAudioActive = TRUE;
}

/*
 * Shutdown
 */
void
syssnd_shutdown(void)
{
}

/*
 * Toggle mute
 *
 * When muted, sounds are still managed but not sent to the dsp, hence
 * it is possible to un-mute at any time.
 */
void
syssnd_toggleMute(void)
{
  sndMute = !sndMute;
}

void
syssnd_vol(S8 d)
{
}

/*
 * Play a sound
 *
 * loop: number of times the sound should be played, -1 to loop forever
 * returns: channel number, or -1 if none was available
 *
 * NOTE if sound is already playing, simply reset it (i.e. can not have
 * twice the same sound playing -- tends to become noisy when too many
 * bad guys die at the same time).
 */
S8
syssnd_play(sound_t *sound, S8 loop)
{
  if (!isAudioActive) return -1;
  if (sound == NULL) return -1;

  GpPcmPlay((U8*)(sound->buf), sound->len, 0);
	return 1;
}

/*
 * Pause
 *
 * pause: TRUE or FALSE
 * clear: TRUE to cleanup all sounds and make sure we start from scratch
 */
void
syssnd_pause(U8 pause, U8 clear)
{
  U8 c;

  if (!isAudioActive) return;
  GpPcmStop();
}

/*
 * Stop a channel
 */
void
syssnd_stop(S8 chan)
{
  GpPcmStop();
}

/* eof */

